"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from openapi_client.api_client import ApiClient, Endpoint as _Endpoint
from openapi_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from openapi_client.model.config_group import ConfigGroup
from openapi_client.model.get_o365_preferred_path_from_v_analytics_request import GetO365PreferredPathFromVAnalyticsRequest


class ConfigurationConfigurationGroupApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_config_group_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [],
                'endpoint_path': '/v1/config-group',
                'operation_id': 'create_config_group',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'body',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'body':
                        (str,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.create_config_group_association_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/v1/config-group/{configGroupId}/device/associate',
                'operation_id': 'create_config_group_association',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'config_group_id',
                    'body',
                ],
                'required': [
                    'config_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'config_group_id':
                        (str,),
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                    'config_group_id': 'configGroupId',
                },
                'location_map': {
                    'config_group_id': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.create_config_group_device_variables_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/v1/config-group/{configGroupId}/device/variables',
                'operation_id': 'create_config_group_device_variables',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'config_group_id',
                    'get_o365_preferred_path_from_v_analytics_request',
                ],
                'required': [
                    'config_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'config_group_id':
                        (str,),
                    'get_o365_preferred_path_from_v_analytics_request':
                        (GetO365PreferredPathFromVAnalyticsRequest,),
                },
                'attribute_map': {
                    'config_group_id': 'configGroupId',
                },
                'location_map': {
                    'config_group_id': 'path',
                    'get_o365_preferred_path_from_v_analytics_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.create_config_group_device_variables1_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/v1/config-group/{configGroupId}/device/variables/schema',
                'operation_id': 'create_config_group_device_variables1',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'config_group_id',
                ],
                'required': [
                    'config_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'config_group_id':
                        (str,),
                },
                'attribute_map': {
                    'config_group_id': 'configGroupId',
                },
                'location_map': {
                    'config_group_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.delete_config_group_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/v1/config-group/{configGroupId}',
                'operation_id': 'delete_config_group',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'config_group_id',
                ],
                'required': [
                    'config_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'config_group_id':
                        (str,),
                },
                'attribute_map': {
                    'config_group_id': 'configGroupId',
                },
                'location_map': {
                    'config_group_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client
        )
        self.delete_config_group_association_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/v1/config-group/{configGroupId}/device/associate',
                'operation_id': 'delete_config_group_association',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'config_group_id',
                    'body',
                ],
                'required': [
                    'config_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'config_group_id':
                        (str,),
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                    'config_group_id': 'configGroupId',
                },
                'location_map': {
                    'config_group_id': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.deploy_config_group_endpoint = _Endpoint(
            settings={
                'response_type': (String,),
                'auth': [],
                'endpoint_path': '/v1/config-group/{configGroupId}/device/deploy',
                'operation_id': 'deploy_config_group',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'config_group_id',
                    'get_o365_preferred_path_from_v_analytics_request',
                ],
                'required': [
                    'config_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'config_group_id':
                        (str,),
                    'get_o365_preferred_path_from_v_analytics_request':
                        (GetO365PreferredPathFromVAnalyticsRequest,),
                },
                'attribute_map': {
                    'config_group_id': 'configGroupId',
                },
                'location_map': {
                    'config_group_id': 'path',
                    'get_o365_preferred_path_from_v_analytics_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.edit_config_group_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [],
                'endpoint_path': '/v1/config-group/{configGroupId}',
                'operation_id': 'edit_config_group',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'config_group_id',
                    'body',
                ],
                'required': [
                    'config_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'config_group_id':
                        (str,),
                    'body':
                        (str,),
                },
                'attribute_map': {
                    'config_group_id': 'configGroupId',
                },
                'location_map': {
                    'config_group_id': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.get_cedge_config_group_schema_by_schema_type_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [],
                'endpoint_path': '/v1/config-group/schema/sdwan',
                'operation_id': 'get_cedge_config_group_schema_by_schema_type',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'schema_type',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'schema_type',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('schema_type',): {

                        "POST": "post",
                        "PUT": "put",
                        "ASSOCIATE/POST": "associate/post",
                        "ASSOCIATE/PUT": "associate/put",
                        "ASSOCIATE/DELETE": "associate/delete",
                        "DEPLOY/POST": "deploy/post"
                    },
                },
                'openapi_types': {
                    'schema_type':
                        (str,),
                },
                'attribute_map': {
                    'schema_type': 'schemaType',
                },
                'location_map': {
                    'schema_type': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_config_group_endpoint = _Endpoint(
            settings={
                'response_type': (ConfigGroup,),
                'auth': [],
                'endpoint_path': '/v1/config-group/{configGroupId}',
                'operation_id': 'get_config_group',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'config_group_id',
                ],
                'required': [
                    'config_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'config_group_id':
                        (str,),
                },
                'attribute_map': {
                    'config_group_id': 'configGroupId',
                },
                'location_map': {
                    'config_group_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_config_group_association_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/v1/config-group/{configGroupId}/device/associate',
                'operation_id': 'get_config_group_association',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'config_group_id',
                ],
                'required': [
                    'config_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'config_group_id':
                        (str,),
                },
                'attribute_map': {
                    'config_group_id': 'configGroupId',
                },
                'location_map': {
                    'config_group_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_config_group_by_solution_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [],
                'endpoint_path': '/v1/config-group',
                'operation_id': 'get_config_group_by_solution',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'solution',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'solution':
                        (str,),
                },
                'attribute_map': {
                    'solution': 'solution',
                },
                'location_map': {
                    'solution': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_config_group_device_configuration_preview_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/v1/config-group/{configGroupId}/device/{deviceId}/preview',
                'operation_id': 'get_config_group_device_configuration_preview',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'config_group_id',
                    'device_id',
                    'get_o365_preferred_path_from_v_analytics_request',
                ],
                'required': [
                    'config_group_id',
                    'device_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'config_group_id':
                        (str,),
                    'device_id':
                        (str,),
                    'get_o365_preferred_path_from_v_analytics_request':
                        (GetO365PreferredPathFromVAnalyticsRequest,),
                },
                'attribute_map': {
                    'config_group_id': 'configGroupId',
                    'device_id': 'deviceId',
                },
                'location_map': {
                    'config_group_id': 'path',
                    'device_id': 'path',
                    'get_o365_preferred_path_from_v_analytics_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.get_config_group_device_variables_endpoint = _Endpoint(
            settings={
                'response_type': ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                'auth': [],
                'endpoint_path': '/v1/config-group/{configGroupId}/device/variables',
                'operation_id': 'get_config_group_device_variables',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'config_group_id',
                    'device_id',
                    'suggestions',
                ],
                'required': [
                    'config_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'config_group_id':
                        (str,),
                    'device_id':
                        (str,),
                    'suggestions':
                        (bool,),
                },
                'attribute_map': {
                    'config_group_id': 'configGroupId',
                    'device_id': 'device-id',
                    'suggestions': 'suggestions',
                },
                'location_map': {
                    'config_group_id': 'path',
                    'device_id': 'query',
                    'suggestions': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_config_group_association_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/v1/config-group/{configGroupId}/device/associate',
                'operation_id': 'update_config_group_association',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'config_group_id',
                    'body',
                ],
                'required': [
                    'config_group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'config_group_id':
                        (str,),
                    'body':
                        ({str: (bool, date, datetime, dict, float, int, list, str, none_type)},),
                },
                'attribute_map': {
                    'config_group_id': 'configGroupId',
                },
                'location_map': {
                    'config_group_id': 'path',
                    'body': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def create_config_group(
        self,
        **kwargs
    ):
        """create_config_group  # noqa: E501

        Create a new Configuration Group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_config_group(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            body (str): Config Group. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.create_config_group_endpoint.call_with_http_info(**kwargs)

    def create_config_group_association(
        self,
        config_group_id,
        **kwargs
    ):
        """create_config_group_association  # noqa: E501

        Create associations with device and a config group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_config_group_association(config_group_id, async_req=True)
        >>> result = thread.get()

        Args:
            config_group_id (str):

        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['config_group_id'] = \
            config_group_id
        return self.create_config_group_association_endpoint.call_with_http_info(**kwargs)

    def create_config_group_device_variables(
        self,
        config_group_id,
        **kwargs
    ):
        """create_config_group_device_variables  # noqa: E501

        assign values to device variables<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_config_group_device_variables(config_group_id, async_req=True)
        >>> result = thread.get()

        Args:
            config_group_id (str): Config Group Id

        Keyword Args:
            get_o365_preferred_path_from_v_analytics_request (GetO365PreferredPathFromVAnalyticsRequest): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['config_group_id'] = \
            config_group_id
        return self.create_config_group_device_variables_endpoint.call_with_http_info(**kwargs)

    def create_config_group_device_variables1(
        self,
        config_group_id,
        **kwargs
    ):
        """create_config_group_device_variables1  # noqa: E501

        assign values to device variables  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_config_group_device_variables1(config_group_id, async_req=True)
        >>> result = thread.get()

        Args:
            config_group_id (str): Config Group Id

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['config_group_id'] = \
            config_group_id
        return self.create_config_group_device_variables1_endpoint.call_with_http_info(**kwargs)

    def delete_config_group(
        self,
        config_group_id,
        **kwargs
    ):
        """delete_config_group  # noqa: E501

        Delete Config Group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_config_group(config_group_id, async_req=True)
        >>> result = thread.get()

        Args:
            config_group_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['config_group_id'] = \
            config_group_id
        return self.delete_config_group_endpoint.call_with_http_info(**kwargs)

    def delete_config_group_association(
        self,
        config_group_id,
        **kwargs
    ):
        """delete_config_group_association  # noqa: E501

        Delete Config Group Association from devices  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_config_group_association(config_group_id, async_req=True)
        >>> result = thread.get()

        Args:
            config_group_id (str):

        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['config_group_id'] = \
            config_group_id
        return self.delete_config_group_association_endpoint.call_with_http_info(**kwargs)

    def deploy_config_group(
        self,
        config_group_id,
        **kwargs
    ):
        """deploy_config_group  # noqa: E501

        deploy config group to devices<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.deploy_config_group(config_group_id, async_req=True)
        >>> result = thread.get()

        Args:
            config_group_id (str): Config Group Id

        Keyword Args:
            get_o365_preferred_path_from_v_analytics_request (GetO365PreferredPathFromVAnalyticsRequest): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            String
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['config_group_id'] = \
            config_group_id
        return self.deploy_config_group_endpoint.call_with_http_info(**kwargs)

    def edit_config_group(
        self,
        config_group_id,
        **kwargs
    ):
        """edit_config_group  # noqa: E501

        Edit a Configuration Group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.edit_config_group(config_group_id, async_req=True)
        >>> result = thread.get()

        Args:
            config_group_id (str):

        Keyword Args:
            body (str): Config Group. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['config_group_id'] = \
            config_group_id
        return self.edit_config_group_endpoint.call_with_http_info(**kwargs)

    def get_cedge_config_group_schema_by_schema_type(
        self,
        **kwargs
    ):
        """get_cedge_config_group_schema_by_schema_type  # noqa: E501

        Get a Cedge famiy Configuration Group Schema by Schema Type  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_cedge_config_group_schema_by_schema_type(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            schema_type (str): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_cedge_config_group_schema_by_schema_type_endpoint.call_with_http_info(**kwargs)

    def get_config_group(
        self,
        config_group_id,
        **kwargs
    ):
        """get_config_group  # noqa: E501

        Get a Configuration Group by ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_config_group(config_group_id, async_req=True)
        >>> result = thread.get()

        Args:
            config_group_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            ConfigGroup
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['config_group_id'] = \
            config_group_id
        return self.get_config_group_endpoint.call_with_http_info(**kwargs)

    def get_config_group_association(
        self,
        config_group_id,
        **kwargs
    ):
        """get_config_group_association  # noqa: E501

        Get devices association with a config group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_config_group_association(config_group_id, async_req=True)
        >>> result = thread.get()

        Args:
            config_group_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['config_group_id'] = \
            config_group_id
        return self.get_config_group_association_endpoint.call_with_http_info(**kwargs)

    def get_config_group_by_solution(
        self,
        **kwargs
    ):
        """get_config_group_by_solution  # noqa: E501

        Get a Configuration Group by Solution  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_config_group_by_solution(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            solution (str): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_config_group_by_solution_endpoint.call_with_http_info(**kwargs)

    def get_config_group_device_configuration_preview(
        self,
        config_group_id,
        device_id,
        **kwargs
    ):
        """get_config_group_device_configuration_preview  # noqa: E501

        Get a preview of the configuration for a device<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_config_group_device_configuration_preview(config_group_id, device_id, async_req=True)
        >>> result = thread.get()

        Args:
            config_group_id (str): Config Group Id
            device_id (str): Device Id

        Keyword Args:
            get_o365_preferred_path_from_v_analytics_request (GetO365PreferredPathFromVAnalyticsRequest): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['config_group_id'] = \
            config_group_id
        kwargs['device_id'] = \
            device_id
        return self.get_config_group_device_configuration_preview_endpoint.call_with_http_info(**kwargs)

    def get_config_group_device_variables(
        self,
        config_group_id,
        **kwargs
    ):
        """get_config_group_device_variables  # noqa: E501

        Get device variables<br><br><br>Note: In a multitenant vManage system, this API is only available in the Provider view.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_config_group_device_variables(config_group_id, async_req=True)
        >>> result = thread.get()

        Args:
            config_group_id (str): Config Group Id

        Keyword Args:
            device_id (str): Comma separated device id's like d1,d2. [optional]
            suggestions (bool): Suggestions for possible values. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['config_group_id'] = \
            config_group_id
        return self.get_config_group_device_variables_endpoint.call_with_http_info(**kwargs)

    def update_config_group_association(
        self,
        config_group_id,
        **kwargs
    ):
        """update_config_group_association  # noqa: E501

        Move the devices from one config group to another  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_config_group_association(config_group_id, async_req=True)
        >>> result = thread.get()

        Args:
            config_group_id (str):

        Keyword Args:
            body ({str: (bool, date, datetime, dict, float, int, list, str, none_type)}): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['config_group_id'] = \
            config_group_id
        return self.update_config_group_association_endpoint.call_with_http_info(**kwargs)




"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_app_hosting_api import RealTimeMonitoringAppHostingApi  # noqa: E501


class TestRealTimeMonitoringAppHostingApi(unittest.TestCase):
    """RealTimeMonitoringAppHostingApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringAppHostingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_app_hosting_attached_devices(self):
        """Test case for get_app_hosting_attached_devices

        """
        pass

    def test_get_app_hosting_details(self):
        """Test case for get_app_hosting_details

        """
        pass

    def test_get_app_hosting_guest_routes(self):
        """Test case for get_app_hosting_guest_routes

        """
        pass

    def test_get_app_hosting_network_devices(self):
        """Test case for get_app_hosting_network_devices

        """
        pass

    def test_get_app_hosting_network_utils(self):
        """Test case for get_app_hosting_network_utils

        """
        pass

    def test_get_app_hosting_processes(self):
        """Test case for get_app_hosting_processes

        """
        pass

    def test_get_app_hosting_storage_utils(self):
        """Test case for get_app_hosting_storage_utils

        """
        pass

    def test_get_app_hosting_utilization(self):
        """Test case for get_app_hosting_utilization

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_network_design_api import ConfigurationNetworkDesignApi  # noqa: E501


class TestConfigurationNetworkDesignApi(unittest.TestCase):
    """ConfigurationNetworkDesignApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationNetworkDesignApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_acquire_attach_lock(self):
        """Test case for acquire_attach_lock

        """
        pass

    def test_acquire_edit_lock(self):
        """Test case for acquire_edit_lock

        """
        pass

    def test_create_network_design(self):
        """Test case for create_network_design

        """
        pass

    def test_edit_network_design(self):
        """Test case for edit_network_design

        """
        pass

    def test_get_device_profile_config_status(self):
        """Test case for get_device_profile_config_status

        """
        pass

    def test_get_device_profile_config_status_by_profile_id(self):
        """Test case for get_device_profile_config_status_by_profile_id

        """
        pass

    def test_get_device_profile_task_count(self):
        """Test case for get_device_profile_task_count

        """
        pass

    def test_get_device_profile_task_status(self):
        """Test case for get_device_profile_task_status

        """
        pass

    def test_get_device_profile_task_status_by_profile_id(self):
        """Test case for get_device_profile_task_status_by_profile_id

        """
        pass

    def test_get_global_parameters(self):
        """Test case for get_global_parameters

        """
        pass

    def test_get_network_design(self):
        """Test case for get_network_design

        """
        pass

    def test_get_service_profile_config(self):
        """Test case for get_service_profile_config

        """
        pass

    def test_push_device_profile_template(self):
        """Test case for push_device_profile_template

        """
        pass

    def test_push_network_design(self):
        """Test case for push_network_design

        """
        pass

    def test_run_my_test(self):
        """Test case for run_my_test

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_cloud_on_ramp_api import ConfigurationCloudOnRampApi  # noqa: E501


class TestConfigurationCloudOnRampApi(unittest.TestCase):
    """ConfigurationCloudOnRampApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationCloudOnRampApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_acquire_resource_pool(self):
        """Test case for acquire_resource_pool

        """
        pass

    def test_add_device_pair(self):
        """Test case for add_device_pair

        """
        pass

    def test_add_transit_vpc(self):
        """Test case for add_transit_vpc

        """
        pass

    def test_authenticate_cloud_on_ramp_cred_and_add(self):
        """Test case for authenticate_cloud_on_ramp_cred_and_add

        """
        pass

    def test_authenticate_cred_and_update(self):
        """Test case for authenticate_cred_and_update

        """
        pass

    def test_create_and_map(self):
        """Test case for create_and_map

        """
        pass

    def test_create_resource_pool(self):
        """Test case for create_resource_pool

        """
        pass

    def test_get_ami_list(self):
        """Test case for get_ami_list

        """
        pass

    def test_get_cloud_accounts(self):
        """Test case for get_cloud_accounts

        """
        pass

    def test_get_cloud_host_vpc_account_details(self):
        """Test case for get_cloud_host_vpc_account_details

        """
        pass

    def test_get_cloud_host_vpcs(self):
        """Test case for get_cloud_host_vpcs

        """
        pass

    def test_get_cloud_list(self):
        """Test case for get_cloud_list

        """
        pass

    def test_get_cloud_mapped_host_accounts(self):
        """Test case for get_cloud_mapped_host_accounts

        """
        pass

    def test_get_cloud_on_ramp_devices(self):
        """Test case for get_cloud_on_ramp_devices

        """
        pass

    def test_get_cor_status(self):
        """Test case for get_cor_status

        """
        pass

    def test_get_external_id(self):
        """Test case for get_external_id

        """
        pass

    def test_get_host_vpcs(self):
        """Test case for get_host_vpcs

        """
        pass

    def test_get_mapped_vpcs(self):
        """Test case for get_mapped_vpcs

        """
        pass

    def test_get_pem_key_list(self):
        """Test case for get_pem_key_list

        """
        pass

    def test_get_tenant_and_host_vpc_list(self):
        """Test case for get_tenant_and_host_vpc_list

        """
        pass

    def test_get_transit_device_pair_and_host_list(self):
        """Test case for get_transit_device_pair_and_host_list

        """
        pass

    def test_get_transit_vpc_supported_size(self):
        """Test case for get_transit_vpc_supported_size

        """
        pass

    def test_get_transit_vpc_vpn_list(self):
        """Test case for get_transit_vpc_vpn_list

        """
        pass

    def test_get_transit_vpcs(self):
        """Test case for get_transit_vpcs

        """
        pass

    def test_map_vpcs(self):
        """Test case for map_vpcs

        """
        pass

    def test_raise_alarm_for_account(self):
        """Test case for raise_alarm_for_account

        """
        pass

    def test_remove_device_id(self):
        """Test case for remove_device_id

        """
        pass

    def test_remove_transit_vpc(self):
        """Test case for remove_transit_vpc

        """
        pass

    def test_scale_down(self):
        """Test case for scale_down

        """
        pass

    def test_scale_up(self):
        """Test case for scale_up

        """
        pass

    def test_unmap_vpcs(self):
        """Test case for unmap_vpcs

        """
        pass

    def test_update_host_vpc_reachability(self):
        """Test case for update_host_vpc_reachability

        """
        pass

    def test_update_transit_vpc(self):
        """Test case for update_transit_vpc

        """
        pass

    def test_update_transit_vpc_autoscale_properties(self):
        """Test case for update_transit_vpc_autoscale_properties

        """
        pass

    def test_updatestatus(self):
        """Test case for updatestatus

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_network_design_templates_api import ConfigurationNetworkDesignTemplatesApi  # noqa: E501


class TestConfigurationNetworkDesignTemplatesApi(unittest.TestCase):
    """ConfigurationNetworkDesignTemplatesApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationNetworkDesignTemplatesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_edit_device_profile_template(self):
        """Test case for edit_device_profile_template

        """
        pass

    def test_edit_global_template(self):
        """Test case for edit_global_template

        """
        pass

    def test_generate_profile_template_list(self):
        """Test case for generate_profile_template_list

        """
        pass

    def test_get_device_profile_feature_template_list(self):
        """Test case for get_device_profile_feature_template_list

        """
        pass

    def test_get_device_profile_template(self):
        """Test case for get_device_profile_template

        """
        pass

    def test_get_global_template(self):
        """Test case for get_global_template

        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.real_time_monitoring_hardware_api import RealTimeMonitoringHardwareApi  # noqa: E501


class TestRealTimeMonitoringHardwareApi(unittest.TestCase):
    """RealTimeMonitoringHardwareApi unit test stubs"""

    def setUp(self):
        self.api = RealTimeMonitoringHardwareApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_alarm_list(self):
        """Test case for create_alarm_list

        """
        pass

    def test_create_environment_list(self):
        """Test case for create_environment_list

        """
        pass

    def test_create_error_alarm_list(self):
        """Test case for create_error_alarm_list

        """
        pass

    def test_create_inventory_list(self):
        """Test case for create_inventory_list

        """
        pass

    def test_create_status_summary(self):
        """Test case for create_status_summary

        """
        pass

    def test_create_synced_alarm_list(self):
        """Test case for create_synced_alarm_list

        """
        pass

    def test_create_synced_environment_list(self):
        """Test case for create_synced_environment_list

        """
        pass

    def test_create_synced_inventory_list(self):
        """Test case for create_synced_inventory_list

        """
        pass

    def test_create_system_list(self):
        """Test case for create_system_list

        """
        pass

    def test_create_temp_threshold_list(self):
        """Test case for create_temp_threshold_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
